'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var PropTypes = _interopDefault(require('prop-types'));

var asyncGenerator = function () {
  function AwaitValue(value) {
    this.value = value;
  }

  function AsyncGenerator(gen) {
    var front, back;

    function send(key, arg) {
      return new Promise(function (resolve, reject) {
        var request = {
          key: key,
          arg: arg,
          resolve: resolve,
          reject: reject,
          next: null
        };

        if (back) {
          back = back.next = request;
        } else {
          front = back = request;
          resume(key, arg);
        }
      });
    }

    function resume(key, arg) {
      try {
        var result = gen[key](arg);
        var value = result.value;

        if (value instanceof AwaitValue) {
          Promise.resolve(value.value).then(function (arg) {
            resume("next", arg);
          }, function (arg) {
            resume("throw", arg);
          });
        } else {
          settle(result.done ? "return" : "normal", result.value);
        }
      } catch (err) {
        settle("throw", err);
      }
    }

    function settle(type, value) {
      switch (type) {
        case "return":
          front.resolve({
            value: value,
            done: true
          });
          break;

        case "throw":
          front.reject(value);
          break;

        default:
          front.resolve({
            value: value,
            done: false
          });
          break;
      }

      front = front.next;

      if (front) {
        resume(front.key, front.arg);
      } else {
        back = null;
      }
    }

    this._invoke = send;

    if (typeof gen.return !== "function") {
      this.return = undefined;
    }
  }

  if (typeof Symbol === "function" && Symbol.asyncIterator) {
    AsyncGenerator.prototype[Symbol.asyncIterator] = function () {
      return this;
    };
  }

  AsyncGenerator.prototype.next = function (arg) {
    return this._invoke("next", arg);
  };

  AsyncGenerator.prototype.throw = function (arg) {
    return this._invoke("throw", arg);
  };

  AsyncGenerator.prototype.return = function (arg) {
    return this._invoke("return", arg);
  };

  return {
    wrap: function (fn) {
      return function () {
        return new AsyncGenerator(fn.apply(this, arguments));
      };
    },
    await: function (value) {
      return new AwaitValue(value);
    }
  };
}();















var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var itemStyle = {
  position: 'relative'
};

var LeftMenu = function LeftMenu(props) {
  var lightThem = {
    background: '#FAFAFA',
    color: '#555555'
  };
  var darkThem = {
    background: '#1E2A4D',
    color: '#FFFFFF'
  };
  var them = props.them || 'light';
  var raperStyle = them === 'light' ? lightThem : darkThem;
  return React.createElement(
    'div',
    { className: 'k2-' + them, style: _extends({}, raperStyle, { overflow: 'auto' }) },
    props.children
  );
};

LeftMenu.propTypes = {
  them: PropTypes.string,
  children: PropTypes.array
};

var SubMenu = function SubMenu(props) {
  return React.createElement(
    'div',
    { style: itemStyle },
    React.createElement(
      'div',
      { className: 'menu_title' },
      props.name
    ),
    props.children
  );
};

SubMenu.propTypes = {
  name: PropTypes.string,
  children: PropTypes.array
};

var MenuItem = function MenuItem(props) {
  return React.createElement(
    'div',
    { style: itemStyle },
    props.icon,
    React.createElement(
      'span',
      {
        className: 'menulist_name' },
      props.name
    )
  );
};

MenuItem.propTypes = {
  icon: PropTypes.node,
  name: PropTypes.string
};

exports.SubMenu = SubMenu;
exports.MenuItem = MenuItem;
exports.LeftMenu = LeftMenu;
//# sourceMappingURL=index.js.map
